# Upstream vm (http://www.wonderworks.com/vm/) seems to be currently
# unmaintained. This package adds the patchset maintained by Robert Widhopf-Fenk
# (http://www.robf.de/Hacking/elisp/vm-7.19.patch.gz). I have manually added a
# version number to the patch filename.
#
# In order to make the PGP stuff work with GNU Emacs <22, I have pulled pgp*.el
# from the GNU Emacs CVS - see Source11-16. These were pulled from CVS on 10th
# February 2007.
#
# Vcard handling has been added - see Source21-22. These were pulled from
# http://www.splode.com/users/friedman/software/emacs-lisp/ on 10th February
# 2007. 
#
# Font-lock support of message bodies was added (Source31) from 
# http://de.geocities.com/ulf_jasper/emacs.html on 10th February 2007.

%define vmversion 7.19
%define vmrfversion devo282

Summary: Emacs VM mailreader
Name: emacs-vm
Version: %{vmversion}.%{vmrfversion}
Release: 9%{?dist}
License: GPL
Group: Applications/Internet
URL: http://www.wonderworks.com/vm/

Source0: http://www.seanet.com/~kylemonger/vm/vm-%{vmversion}.tar.gz
Source1: pixmaps-small-fuzzy.tar.gz
Source11: pgg.el
Source12: pgg-def.el
Source13: pgg-gpg.el
Source14: pgg-parse.el
Source15: pgg-pgp.el
Source16: pgg-pgp5.el
Source21: vcard.el
Source22: vm-vcard.el
Source31: u-vm-color.el
Patch0: vm-7.19-devo-282.patch.gz

Requires: emacs
Requires(pre): /sbin/install-info 
Requires(post): /sbin/install-info 
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Buildrequires: emacs texinfo

%description
VM (View Mail) is an Emacs subsystem that allows UNIX mail to be read
and disposed of within Emacs.  Commands exist to do the normal things
expected of a mail user agent, such as generating replies, saving
messages to folders, deleting messages and so on.  There are other
more advanced commands that do tasks like bursting and creating
digests, message forwarding, and organizing message presentation
according to various criteria. 

This package includes Robert widhopf-Fenk's patchset %{vmrfversion}
(http://www.robf.de/Hacking/elisp/). Please read that webpage to find
out how to configure the extra features offered by that patchset.

%package el
Group: Applications/Internet
Summary: Elisp source files for VM mailreader for emacs
Requires: %{name} = %{version}-%{release}

%description el 
The %{name}-el package contains the elisp source files for the %{name}
package. It is not necessary to install this if you want to run vm.

%prep
%setup -q -n vm-%{vmversion}

tar -zxf %SOURCE1
cp pixmaps-small-fuzzy/* pixmaps/

%patch0 -p1 
mv Makefile Makefile.bk
sed -e 's/mkdirhier/mkdir -p/g' Makefile.bk > Makefile

cp %{SOURCE11} .
cp %{SOURCE12} .
cp %{SOURCE13} .
cp %{SOURCE14} .
cp %{SOURCE15} .
cp %{SOURCE16} .
cp %{SOURCE21} .
cp %{SOURCE22} .
cp %{SOURCE31} .

%build
%define pkgdir %{_datadir}/emacs/site-lisp/vm
%define pixmapdir %{pkgdir}/pixmaps

export CFLAGS="$RPM_OPT_FLAGS"

make %{?_smp_mflags} all \
	prefix=%{_prefix} \
  	INFODIR=%{_infodir} \
  	LISPDIR=%{pkgdir} \
  	BINDIR=%{_bindir} \
  	PIXMAPDIR=%{pixmapdir} \
	EMACS=emacs

%install
rm -rf %{buildroot}
echo %{buildroot}%{_prefix} 
make install \
  	prefix=%{buildroot}%{_prefix} \
  	INFODIR=%{buildroot}%{_infodir} \
  	LISPDIR=%{buildroot}%{pkgdir} \
  	BINDIR=%{buildroot}%{_bindir} \
  	PIXMAPDIR=%{buildroot}%{pixmapdir}

cp *.el %{buildroot}%{pkgdir}

%define startd %{_datadir}/emacs/site-lisp/site-start.d/
%define initfile %{startd}/vm-mode-init.el

# Create initialization file.
install -d %{buildroot}/%{startd}
cat > %{buildroot}/%{initfile} <<EOF
(setq vm-toolbar-pixmap-directory "%{pixmapdir}")
(setq vm-image-directory "%{pixmapdir}")
(autoload 'vm "vm" "Start VM on your primary inbox." t)
(autoload 'vm-other-frame "vm" "Like \`vm' but starts in another frame." t)
(autoload 'vm-visit-folder "vm" "Start VM on an arbitrary folder." t)
(autoload 'vm-visit-virtual-folder "vm" "Visit a VM virtual folder." t)
(autoload 'vm-mode "vm" "Run VM major mode on a buffer" t)
(autoload 'vm-mail "vm" "Send a mail message using VM." t)
(autoload 'vm-submit-bug-report "vm" "Send a bug report about VM." t)

;; Settings for u-vm-color.el 
(require 'u-vm-color)
(add-hook 'vm-summary-mode-hook 'u-vm-color-summary-mode)
(add-hook 'vm-select-message-hook 'u-vm-color-fontify-buffer)
EOF

%clean
rm -rf %{buildroot}

%post 
# Without the --entry part here, we get a malformed entry in info.
/sbin/install-info \
  --entry="* VM: (vm).       An Emacs mailreader" \
  %{_infodir}/vm.info.gz %{_infodir}/dir 2>/dev/null || :

%preun
if [ "$1" = "0" ] ; then 
 /sbin/install-info --delete %{_infodir}/vm.info.gz %{_infodir}/dir 2>/dev/null || :
fi

%files
%defattr(-,root,root,-)
%doc README COPYING
%doc %{_infodir}/*
%{_bindir}/*
%{pixmapdir}
%{pkgdir}/*.elc
%{initfile}
%dir %{pkgdir}

%files el
%defattr(-,root,root,-)
%{pkgdir}/*.el

%changelog
* Sun Mar 18 2007 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 7.19.devo282-9
- Bump release to fix problem with CVS sources file

* Sun Mar 18 2007 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 7.19.devo282-8
- Redefine version to include vmrf patch version (devo282)
- Remove pointless %%{pkg} macro
- Add new pixmaps with better sizing (still ugly though)
- Renamed the vmrf patch to include the version

* Sat Feb 10 2007 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 7.19-7
- Added pgg*.el from Emacs 22 CVS
- Added u-vm-color.el from http://de.geocities.com/ulf_jasper/emacs.html
- Added vcard support from http://www.splode.com/users/friedman/software/emacs-lisp/
- Fixed name of info files in pre and post scripts

* Sat Feb  3 2007 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 7.19-5
- Add patch from http://www.robf.de/Hacking/elisp/ (resolves bug 224501)
- Ensure CFLAGS="$RPM_OPT_FLAGS" (bug 225101)

* Mon Aug 28 2006 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 7.19-4
- Bump release for FC-6 mass rebuild

* Tue Jun 20 2006 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 7.19-3
- Change group to Applications/Internet
- Add release tag to the Requires for the -el package

* Tue May 23 2006 Jonathan G. Underwood <jonathan.underwood@gmail.com> - 7.19-2
- Clean up spec file

* Fri Sep  2 2005 Jonathan Underwood <jonathan.underwood@gmail.com> - 7.19-1.fc4.jgu
- Initial build
- Generate vm-mode-init.el
- Separate out *.el files into -el package
- Added patch to remove warnings in the decode and encode programs
